# tlvPlay
Generic TLV Parser based on TLV and related standards
<BR>Can parse any Simple or BER TLV upto **nth Level** automatically.
<BR>Multi byte Tag, Multi byte Length is also Supported.

# Stats

[![GitHub License](https://img.shields.io/github/license/impratikjaiswal/tlvPlay)](LICENSE)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)

[![GitHub Release](https://img.shields.io/github/v/release/impratikjaiswal/tlvPlay)](https://github.com/impratikjaiswal/tlvPlay/releases/latest)
[![GitHub commits since latest release](https://img.shields.io/github/commits-since/impratikjaiswal/tlvPlay/latest)](https://github.com/impratikjaiswal/tlvPlay/commits/main/)

[![Static Badge](https://img.shields.io/badge/amenitypj.in/tlvPlay-a?label=website%20url)](https://amenitypj.in/tlvPlay)
[![Website](https://img.shields.io/website?url=https://amenitypj.in/tlvPlay&label=website%20status)](https://amenitypj.in/tlvPlay)

[![Static Badge](https://img.shields.io/badge/impratikjaiswal.github.io/tlvPlay-a?label=gihub%20website%20url)](https://impratikjaiswal.github.io/tlvPlay)
[![Website](https://img.shields.io/website?url=https://impratikjaiswal.github.io/tlvPlay&label=website%20status)](https://impratikjaiswal.github.io/tlvPlay)

# Url(s) of AmenityPj

Refer [Url(s) of AmenityPj](https://impratikjaiswal.github.io/amenitypj/#urls-of-amenitypj) for details.

# Screen Shot(s) of Web App [![Static Badge](https://img.shields.io/badge/amenitypj.in-a)](https://amenitypj.in/) 
![sample_web_1](https://github.com/impratikjaiswal/tlvPlay/blob/main/static/images/sample_web_1.gif?raw=true)

# Installation/Setup

Steps can be found [here](https://github.com/impratikjaiswal/pythonHelpers/blob/main/HOW_TO_INSTALL_PYTHON_APPS.md).

# How To Use

There are various ways to Get Started:

- Online Mode
    - Website [![Static Badge](https://img.shields.io/badge/amenitypj.in-a)](https://amenitypj.in) can be used
- Offline Mode (Requires Download / Cloning of the Repo)
    - Code can be directly run from ```tlvPlay/tlv_play/main/tlvplay.py``` using any IDE
    - Local Web Server App [amenitypj](https://github.com/impratikjaiswal/amenitypj) can be used

# Help

Issue tracker can be found [here](CONTRIBUTING.md#issue-tracker).

# Contributing

- Code of Conduct can be found [here](CODE_OF_CONDUCT.md).
- Contributing Guidelines can be found [here](CONTRIBUTING.md).
